@@ -50,7 +50,7 @@ class TestKDPFromPHIDP:
     az = 360
     rng = 1000
     pad = window // 2
-    kdp_true = np.arange(az * rng, dtype=np.float).reshape(az, rng)
+    kdp_true = np.arange(az * rng, dtype=np.float_).reshape(az, rng)
     phidp_true = np.power(kdp_true, 2)
     dr = 0.1
     kdp_true /= dr
