@@ -17,7 +17,12 @@ import xarray as xr
 
 from wradlib import georef, io, util, zonalstats
 
-from . import get_wradlib_data_file, requires_data, requires_secrets
+from . import (
+    get_wradlib_data_file,
+    requires_data,
+    requires_secrets,
+    requires_xarray_backend_api,
+)
 
 
 @pytest.fixture(params=["file", "filelike"])
@@ -376,6 +381,67 @@ class TestHDF5:
 
         io.hdf.read_trmm(trmm_2a23_file, trmm_2a25_file, bbox)
 
+    @requires_data
+    @requires_xarray_backend_api
+    @pytest.mark.parametrize(
+        "opener", [io.hdf.open_odim_dataset, io.hdf.open_odim_mfdataset]
+    )
+    def test_open_odim_functions(self, opener):
+        filename = "hdf5/knmi_polar_volume.h5"
+        with get_wradlib_data_file(filename, "file") as odim_file:
+            ds = opener(odim_file)
+            assert isinstance(ds, io.xarray.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(odim_file, group="dataset1")
+            assert isinstance(ds, xr.Dataset)
+            ds = opener(odim_file, reindex_angle=False)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(odim_file, reindex_angle=True)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(odim_file, reindex_angle=0.4)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+
+    @requires_data
+    @requires_xarray_backend_api
+    @pytest.mark.parametrize(
+        "opener", [io.hdf.open_gamic_dataset, io.hdf.open_gamic_mfdataset]
+    )
+    def test_open_gamic_functions(self, opener):
+        filename = "hdf5/DWD-Vol-2_99999_20180601054047_00.h5"
+        with get_wradlib_data_file(filename, "file") as gamic_file:
+            ds = opener(gamic_file)
+            assert isinstance(ds, io.xarray.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(gamic_file, group="scan0")
+            assert isinstance(ds, xr.Dataset)
+            ds = opener(gamic_file, reindex_angle=False)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(gamic_file, reindex_angle=True)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+            ds = opener(gamic_file, reindex_angle=0.4)
+            assert isinstance(ds, io.RadarVolume)
+            for d in ds:
+                assert isinstance(d, xr.Dataset)
+
+
+def radolan_files():
+    from pathlib import Path
+
+    path = os.path.join(util.get_wradlib_data_path(), "radolan")
+    return [p for p in Path(path).rglob("raa*.gz")]
+
 
 class TestRadolan:
     def test_get_radolan_header_token(self):
@@ -1051,6 +1117,16 @@ class TestRadolan:
         assert data.time[0].values == np.datetime64("2014-08-03T09:50:00.000000000")
         assert data.time[1].values == np.datetime64("2014-08-10T20:50:00.000000000")
 
+    @requires_data
+    @pytest.mark.parametrize("radfile", radolan_files())
+    def test_read_radolan_data_files(self, radfile):
+        data = io.radolan.open_radolan_dataset(str(radfile))
+        assert isinstance(data, xr.Dataset)
+        name = list(data.variables.keys())[0]
+        var = data[name]
+        assert isinstance(var, xr.DataArray)
+        assert isinstance(var.values, np.ndarray)
+
 
 class TestRainbow:
     @requires_data
@@ -1290,6 +1366,23 @@ class TestIris:
         assert data._record_number == 511
         assert data.filepos == 3139584
 
+    @requires_data
+    def test_open_iris_cartesian_product(self):
+        filename = "sigmet/SUR160703220000.MAX71NP.gz"
+        with get_wradlib_data_file(filename, "filelike") as sigmetfile:
+            data = io.iris.IrisCartesianProductFile(
+                sigmetfile, loaddata=True, origin="lower"
+            )
+        assert isinstance(data.rh, io.iris.IrisRecord)
+        assert isinstance(data.fh, (np.memmap, np.ndarray))
+
+    @requires_data
+    def test_iris_cartesian_product_origin_future_warning(self):
+        filename = "sigmet/SUR160703220000.MAX71NP.gz"
+        with get_wradlib_data_file(filename, "filelike") as sigmetfile:
+            with pytest.warns(FutureWarning):
+                io.iris.IrisCartesianProductFile(sigmetfile, loaddata=True, origin=None)
+
     @requires_data
     def test_read_iris(self, file_or_filelike):
         filename = "sigmet/cor-main131125105503.RAW2049"
