@@ -62,7 +62,7 @@ volume data:
     >>> gridshape = (len(z), len(y), len(x))
     >>> # create an instance of the CAPPI class and
     >>> # use it to create a series of CAPPIs
-    >>> gridder = wradlib.vpr.CAPPI(polxyz, xyz, gridshape=gridshape, maxrange=ranges.max(),  # noqa
+    >>> gridder = wradlib.vpr.CAPPI(polxyz, xyz, maxrange=ranges.max(),  # noqa
     ...                             minelev=elevs.min(), maxelev=elevs.max(),
     ...                             ipclass=wradlib.ipol.Idw)
     >>> gridded = np.ma.masked_invalid( gridder(poldata) ).reshape(gridshape)
@@ -83,12 +83,17 @@ volume data:
 __all__ = [
     "volcoords_from_polar",
     "make_3d_grid",
+    "norm_vpr_stats",
     "CartesianVolume",
     "CAPPI",
     "PseudoCAPPI",
+    "out_of_range",
+    "blindspots",
 ]
 __doc__ = __doc__.format("\n   ".join(__all__))
 
+import warnings
+
 import numpy as np
 
 from wradlib import georef, ipol, util
@@ -104,13 +109,15 @@ class CartesianVolume:
         of shape (num bins, 3)
     gridcoords : :class:`numpy:numpy.ndarray`
         of shape (num voxels, 3)
-    gridshape : tuple
-        shape of the Cartesian grid (num x, num y, num z)
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    ipclass : object
+    minelev : float
+        The minimum elevation angle of the volume (degree)
+    maxelev : float
+        The maximum elevation angle of the volume (degree)
+    ipclass : :class:`wradlib.ipol.IpolBase`
         an interpolation class from :mod:`wradlib.ipol`
-    ipargs : `**kwargs`
+    ipargs : dict
         keyword arguments corresponding to ``ipclass``
 
     Returns
@@ -134,6 +141,12 @@ class CartesianVolume:
         ipclass=ipol.Idw,
         **ipargs,
     ):
+        if gridshape is not None:
+            warnings.warn(
+                f"``gridshape`` is not used in {self.__class__}. "
+                f"It will be removed in wradlib version 2.0.",
+                DeprecationWarning,
+            )
         # radar location in Cartesian coordinates
         # TODO: pass projected radar location as argument
         # (allows processing of incomplete polar volumes)
@@ -145,9 +158,7 @@ class CartesianVolume:
             ]
         ).reshape((-1, 3))
         # Set the mask which masks the blind voxels of the 3-D volume grid
-        self.mask = self._get_mask(
-            gridcoords, polcoords, gridshape, maxrange, minelev, maxelev
-        )
+        self.mask = self._get_mask(gridcoords, polcoords, maxrange, minelev, maxelev)
         # create an instance of the Interpolation class
         self.trgix = np.where(np.logical_not(self.mask))
         self.ip = ipclass(src=polcoords, trg=gridcoords[self.trgix], **ipargs)
@@ -177,7 +188,6 @@ class CartesianVolume:
         self,
         gridcoords,
         polcoords=None,
-        gridshape=None,
         maxrange=None,
         minelev=None,
         maxelev=None,
@@ -192,11 +202,9 @@ class CartesianVolume:
         Parameters
         ----------
         gridcoords : :class:`numpy:numpy.ndarray`
-            of shape (num voxels, 3)
+            Array of shape (num voxels, 3)
         polcoords : :class:`numpy:numpy.ndarray`
-            of shape (num bins, 3)
-        gridshape : tuple
-            shape of the Cartesian grid (num x, num y, num z)
+            Array of shape (num bins, 3)
         maxrange : float
             The maximum radar range
             (must be the same for each elevation angle,
@@ -210,7 +218,6 @@ class CartesianVolume:
         -------
         output : :class:`numpy:numpy.ndarray`
             Boolean array of length (num voxels,)
-
         """
         return np.repeat(False, len(gridcoords))
 
@@ -230,19 +237,15 @@ class CAPPI(CartesianVolume):
     ----------
     polcoords : :class:`numpy:numpy.ndarray`
         coordinate array of shape (num bins, 3)
-        Represents the 3-D coordinates of the orginal radar bins
-    gridcoords : :func:`numpy:numpy.array`
+        Represents the 3-D coordinates of the original radar bins
+    gridcoords : :class:`numpy:numpy.ndarray`
         coordinate array of shape (num voxels, 3)
         Represents the 3-D coordinates of the Cartesian grid
-    gridshape : tuple
-        shape of the original polar volume (num elevation angles,
-        num azimuth angles, num range bins)
-        size must correspond to length of polcoords
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    ipclass : object
+    ipclass : :class:`wradlib.ipol.IpolBase`
         an interpolation class from :mod:`wradlib.ipol`
-    ipargs : `**kwargs`
+    ipargs : dict
         keyword arguments corresponding to ``ipclass``
 
     Returns
@@ -252,15 +255,15 @@ class CAPPI(CartesianVolume):
 
     See Also
     --------
-    out_of_range
-    blindspots
+    :func:`~wradlib.vpr.out_of_range`
+    :func:`~wradlib.vpr.blindspots`
 
     Examples
     --------
     See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
 
-    def _get_mask(self, gridcoords, polcoords, gridshape, maxrange, minelev, maxelev):
+    def _get_mask(self, gridcoords, polcoords, maxrange, minelev, maxelev):
         """Masks the "blind" voxels of the Cartesian 3D-volume
 
         For the CAPPI, blind voxels are below `minelev` and above `maxelev`
@@ -292,19 +295,19 @@ class PseudoCAPPI(CartesianVolume):
     ----------
     polcoords : :class:`numpy:numpy.ndarray`
         coordinate array of shape (num bins, 3)
-        Represents the 3-D coordinates of the orginal radar bins
+        Represents the 3-D coordinates of the original radar bins
     gridcoords : :class:`numpy:numpy.ndarray`
         coordinate array of shape (num voxels, 3)
         Represents the 3-D coordinates of the Cartesian grid
-    gridshape : tuple
-        shape of the original polar volume (num elevation angles,
-        num azimuth angles, num range bins)
-        size must correspond to length of polcoords
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    ipclass : object
+    minelev : float
+        The minimum elevation angle of the volume (degree)
+    maxelev : float
+        The maximum elevation angle of the volume (degree)
+    ipclass : :class:`wradlib.ipol.IpolBase`
         an interpolation class from :mod:`wradlib.ipol`
-    ipargs : `**kwargs`
+    ipargs : dict
         keyword arguments corresponding to ``ipclass``
 
     Returns
@@ -314,14 +317,14 @@ class PseudoCAPPI(CartesianVolume):
 
     See Also
     --------
-    out_of_range
+    :func:`~wradlib.vpr.out_of_range`
 
     Examples
     --------
     See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
 
-    def _get_mask(self, gridcoords, polcoords, gridshape, maxrange, minelev, maxelev):
+    def _get_mask(self, gridcoords, polcoords, maxrange, minelev, maxelev):
         """Masks the "blind" voxels of the Cartesian 3D-volume grid
 
         For the Pseudo CAPPI, blind voxels are only those beyond `maxrange`.
@@ -375,8 +378,9 @@ def blindspots(center, gridcoords, minelev, maxelev, maxrange):
 
     Returns
     -------
-    output : tuple of three Boolean arrays each of length (num grid points)
-
+    output : tuple
+        tuple of three boolean arrays (below, above, out_of_range) each of length
+        (num grid points)
     """
     # distances of 3-D grid nodes from radar site (center)
     dist_from_rad = np.sqrt(((gridcoords - center) ** 2).sum(axis=-1))
@@ -398,19 +402,23 @@ def volcoords_from_polar(sitecoords, elevs, azimuths, ranges, proj=None):
 
     Parameters
     ----------
-    sitecoords : sequence of three floats indicating the radar position
+    sitecoords : tuple
+        sequence of three floats indicating the radar position
         (longitude in decimal degrees, latitude in decimal degrees,
         height a.s.l. in meters)
-    elevs : sequence of elevation angles
-    azimuths : sequence of azimuth angles
-    ranges : sequence of ranges
-    proj : osr spatial reference object
+    elevs : sequence
+        sequence of elevation angles
+    azimuths : sequence
+        sequence of azimuth angles
+    ranges : sequence
+        sequence of ranges
+    proj : :py:class:`gdal:osgeo.osr.SpatialReference`
         GDAL OSR Spatial Reference Object describing projection
 
     Returns
     -------
-    output :  :class:`numpy:numpy.ndarray`
-        (num volume bins, 3)
+    output : :class:`numpy:numpy.ndarray`
+        Array of shape (num volume bins, 3)
 
     Examples
     --------
@@ -434,19 +442,23 @@ def volcoords_from_polar_irregular(sitecoords, elevs, azimuths, ranges, proj=Non
 
     Parameters
     ----------
-    sitecoords : sequence of three floats indicating the radar position
+    sitecoords : tuple
+        sequence of three floats indicating the radar position
         (longitude in decimal degrees, latitude in decimal degrees,
         height a.s.l. in meters)
-    elevs : sequence of elevation angles
-    azimuths : sequence of azimuth angles
-    ranges : sequence of ranges
-    proj : object
+    elevs : sequence
+        sequence of elevation angles
+    azimuths : sequence
+        sequence of azimuth angles
+    ranges : sequence
+        sequence of ranges
+    proj : :py:class:`gdal:osgeo.osr.SpatialReference`
         GDAL OSR Spatial Reference Object describing projection
 
     Returns
     -------
     output : :class:`numpy:numpy.ndarray`
-        (num volume bins, 3)
+        Array of shape (num volume bins, 3)
 
     """
     # check structure: Are azimuth angles and range bins the same for each
@@ -530,7 +542,7 @@ def make_3d_grid(sitecoords, proj, maxrange, maxalt, horiz_res, vert_res, minalt
     ----------
     sitecoords : tuple
         Radar location coordinates in lon, lat
-    proj : object
+    proj : :py:class:`gdal:osgeo.osr.SpatialReference`
         GDAL OSR Spatial Reference Object describing projection
     maxrange : float
         maximum radar range (same unit as SRS defined by ``proj``,
@@ -587,7 +599,7 @@ def synthetic_polar_volume(coords):
     return out
 
 
-def norm_vpr_stats(volume, reference_layer, stat=np.mean, **kwargs):
+def norm_vpr_stats(volume, reference_layer, stat=None, **kwargs):
     """Returns the average normalised vertical profile of a volume or \
     any other desired statistics
 
@@ -599,24 +611,27 @@ def norm_vpr_stats(volume, reference_layer, stat=np.mean, **kwargs):
     Parameters
     ----------
     volume : :class:`numpy:numpy.ndarray` or
-        :class:`numpy.ma.core.MaskedArray`
+        :class:`numpy:numpy.ma.MaskedArray`
         Cartesian 3-d grid with shape (num vertical layers, num x intervals,
         num y intervals)
-    reference_layer : integer
+    reference_layer : int
         This index defines the vertical layers of ``volume`` that is used to
         normalise all vertical profiles
-    stat : function
+    stat : callable
         typically a numpy statistics function (defaults to numpy.mean)
-    kwargs : further keyword arguments taken by ``stat``
+    kwargs : dict
+        further keyword arguments taken by ``stat``
 
     Returns
     -------
-    output : :class:`numpy:numpy.ndarray` or :class:`numpy.ma.core.MaskedArray`
-        of shape (num vertical layers,) which provides the statistic from
+    output : :py:class:`numpy:numpy.ndarray` or :py:class:`numpy:numpy.ma.MaskedArray`
+        Array of shape (num vertical layers,) which provides the statistic from
         ``stat`` applied over all normalised vertical profiles (e.g. the
-        mean normalised vertical profile if numpy.mean is used)
+        mean normalised vertical profile if :py:func:`numpy:numpy.mean` is used)
 
     """
+    if stat is None:
+        stat = np.mean
     tmp = volume / volume[reference_layer]
     return stat(tmp.reshape((-1, np.prod(tmp.shape[-2:]))), axis=1, **kwargs)
 
